<?php declare(strict_types=1);

namespace App\EventListener;


use App\Entity\DrinkType;
use App\Entity\PropertyChangeLog;
use App\Service\DrinkTypeUpdate;
use Doctrine\Bundle\DoctrineBundle\Attribute\AsDoctrineListener;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Events;
use Doctrine\Persistence\Event\LifecycleEventArgs;

#[AsDoctrineListener(event: Events::postPersist)]
#[AsDoctrineListener(event: Events::postUpdate)]
final class PostPersistUpdateListener
{
    public function __construct(private DrinkTypeUpdate $drinkTypeUpdate) {}
    public function postPersist(LifecycleEventArgs $args): void
    {
        $this->log(Events::postPersist, $args);
    }

    public function postUpdate(LifecycleEventArgs $args): void
    {
        $this->log(Events::postUpdate, $args);
    }
   private function log(string $action, LifecycleEventArgs $args): void
   {
       $entity = $args->getObject();
       match($entity::class) {
           DrinkType::class => $this->drinkTypeUpdate->handleLog($action, $entity, $args->getObjectManager()),
           default => null,
       };
   }
}
