<?php

declare(strict_types=1);

namespace App\Repository;

use App\Entity\SystemConfig;
use App\Enum\SystemSettingKey;
use Doctrine\ORM\EntityManagerInterface;

/**
 * @extends AbstractRepository<SystemConfig>
 */
class SystemConfigRepository extends AbstractRepository
{
    public function __construct(EntityManagerInterface $entityManager)
    {
        parent::__construct($entityManager, $entityManager->getClassMetadata(SystemConfig::class));
    }

    public function findByKey(SystemSettingKey $key): SystemConfig
    {
        $config = $this->findOneBy([
            'key' => $key,
        ]);
        if (!($config instanceof SystemConfig)) {
            $config = new SystemConfig();
            $config->setKey($key);
            $config->setValue($key->defaultValue($key));
            $this->save($config);
        }
        return $config;
    }
}
